@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '0.83';
+our $VERSION = '0.86';
 
 
 ###############################################################################
@@ -73,6 +73,7 @@ sub _assemble_xml_file {
     $self->_write_company();
     $self->_write_links_up_to_date();
     $self->_write_shared_doc();
+    $self->_write_hyperlink_base();
     $self->_write_hyperlinks_changed();
     $self->_write_app_version();
 
@@ -366,6 +367,23 @@ sub _write_shared_doc {
 }
 
 
+###############################################################################
+#
+# _write_hyperlink_base()
+#
+# Write the <HyperlinkBase> element.
+#
+sub _write_hyperlink_base {
+
+    my $self = shift;
+    my $data = $self->{_properties}->{hyperlink_base};
+
+    return unless $data;
+
+    $self->xml_data_element( 'HyperlinkBase', $data );
+}
+
+
 ###############################################################################
 #
 # _write_hyperlinks_changed()
